@@ -1,7 +1,7 @@
 #ifndef fooaddresshfoo
 #define fooaddresshfoo
 
-/* $Id: address.h 874 2005-10-26 01:34:48Z lennart $ */
+/* $Id: address.h 1336 2006-12-11 09:34:00Z lathiat $ */
 
 /***
   This file is part of avahi.
@@ -73,9 +73,9 @@ typedef struct AvahiAddress {
     AvahiProtocol proto; /**< Address family */
 
     union {
-        AvahiIPv6Address ipv6;  /** Address when IPv6 */
-        AvahiIPv4Address ipv4;  /** Address when IPv4 */
-        uint8_t data[1];        /** Type independant data field */
+        AvahiIPv6Address ipv6;  /**< Address when IPv6 */
+        AvahiIPv4Address ipv4;  /**< Address when IPv4 */
+        uint8_t data[1];        /**< Type independant data field */
     } data;
 } AvahiAddress;
 
