@@ -1,7 +1,7 @@
 #ifndef QAVAHI_H
 #define QAVAHI_H
 
-/* $Id: qt-watch.h 497 2005-08-30 01:19:54Z lennart $ */
+/* $Id: qt-watch.h 872 2005-10-26 01:21:30Z lennart $ */
 
 /***
   This file is part of avahi.
@@ -26,17 +26,11 @@
 
 #include <avahi-common/watch.h>
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
 AVAHI_C_DECL_BEGIN
-#endif
-
-/**
-Setup abstract poll structure for integration with Qt main loop  */
 
+/** Setup abstract poll structure for integration with Qt main loop  */
 const AvahiPoll* avahi_qt_poll_get(void);
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
 AVAHI_C_DECL_END
-#endif
 
 #endif
