@@ -1,4 +1,4 @@
-/* $Id: avahi-publish.c 1258 2006-08-22 01:48:13Z lennart $ */
+/* $Id: avahi-publish.c 1358 2006-12-31 16:52:13Z lennart $ */
 
 /***
   This file is part of avahi.
@@ -290,7 +290,7 @@ static int parse_command_line(Config *c, const char *argv0, int argc, char *argv
                 c->subtypes = avahi_string_list_add(c->subtypes, optarg);
                 break;
             default:
-                fprintf(stderr, "Invalid command line argument: %c\n", o);
+                fprintf(stderr, "Invalid command line argument: %s\n", argv[optind-1]);
                 return -1;
         }
     }
